;; miscbits-generate-loaddefs.el -- create miscbits-el-loaddefs.el file

;; Copyright 2009, 2010, 2012, 2015 Kevin Ryde.

;; Author: Kevin Ryde <user42_kevin@yahoo.com.au>
;; Keywords: miscbits-el
;; URL: http://user42.tuxfamily.org/miscbits-el/index.html

;; This file is part of miscbits-el.
;;
;; miscbits-el is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the
;; Free Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; miscbits-el is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
;; Public License for more details.
;;
;; You should have received a copy of the GNU General Public License along
;; with miscbits-el; see the file COPYING.  Failing that, go to
;; <http://www.gnu.org/licenses/>.

;;; Commentary:

;; Usage: emacs -batch -q -no-site-file \
;;          -l miscbits-generate-loaddefs.el \
;; 	    -f my-loaddefs-batch \
;; 	    foo.el bar.el ...
;;
;; Create file miscbits-el-loaddefs.el of loaddefs for the .el files on the
;; command line (ie. `command-line-args-left').
;;
;; This is designed for use in any emacs.  `generate-file-autoloads' varies
;; a little in each so the loaddefs should match the version in use.  In
;; particular emacs22 and up generates extra stuff for customize that
;; doesn't work when run in earlier emacs.

;;; Code:

(require 'autoload)

(unless (fboundp 'dolist)
  (require 'cl))

;;-----------------------------------------------------------------------------

(defun my-loaddefs-files (file-list)
  "Create miscbits-el-loaddefs.el from the given FILE-LIST."

  (let* ((basename "miscbits-el-loaddefs.el")
         (fullname (expand-file-name basename)))
    ;; this influences relative path shown
    (setq generated-autoload-file fullname)

    (find-file generated-autoload-file)
    (erase-buffer)
    (insert ";; " basename " -- generated by miscbits-generate-loaddefs.el -- DO NOT EDIT

;; Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Kevin Ryde.

;; Author: Kevin Ryde <user42_kevin@yahoo.com.au>
;; Keywords: miscbits-el
;; URL: http://user42.tuxfamily.org/miscbits-el/index.html

;; This file is part of miscbits-el.
;;
;; miscbits-el is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the
;; Free Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; miscbits-el is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
;; Public License for more details.
;;
;; You should have received a copy of the GNU General Public License along
;; with miscbits-el; see the file COPYING.  Failing that, go to
;; <http://www.gnu.org/licenses/>.

;;; Commentary:

;; The various function, variable and customize autoloads for miscbits-el.
;; This is designed to be loaded at emacs startup.  Docstrings are truncated
;; to one line each to save a bit of file size.

;;; Code:

")

    (insert ";; Generated in:\n")
    (let ((start (point)))
      (insert (emacs-version))
      (comment-region start (point) 2))
    (insert "\n\n")

    (require 'autoload)
    (let ((print-level nil))
      (dolist (filename file-list)
        (generate-file-autoloads filename)))

    (insert "
\(provide 'miscbits-el-loaddefs)

;;; miscbits-el-loaddefs.el ends here
")

    ;; don't want a backup
    (set (make-local-variable 'backup-inhibited) t)
    (save-buffer)

    (message "%s" (shell-command-to-string
                   (concat "ls -l " (shell-quote-argument basename))))
    (goto-char (point-min))))

(defun my-loaddefs-batch ()
  (my-loaddefs-files command-line-args-left))

(provide 'miscbits-generate-loaddefs)

;;; miscbits-generate-loaddefs.el ends here
